library soliq_id;

import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import '.lib/src/data/bloc/soliq_id_bloc.dart';
import '.lib/src/data/di/di_container.dart';
import '.lib/src/data/repository/soliq_id_repository.dart';
import '.lib/src/data/storages/preference.dart';
import '.lib/src/utils/localizations_util.dart';
import '.lib/src/screens/face_id_signin.dart';


class SoliqId extends StatefulWidget {
  const SoliqId({
    Key? key,
    required this.pinfl,
    required this.localizationType,
    required this.guid,
  }) : super(key: key);
  final pinfl;
  final LocalizationType localizationType;
  final String guid;

  @override
  State<SoliqId> createState() => _SoliqIdState();
}

class _SoliqIdState extends State<SoliqId> {
  // todo - add preference to singleton
  Preference preference = Preference();

  @override
  void initState() async {
    super.initState();

    final locale = getLocalizationType(
      widget.localizationType,
    );
    getGuid();
    BlocProvider.of<SoliqIdBloc>(context).add(SoliqIdAccountInfoEvent(
        pinfl: widget.pinfl, projectId: 0, lang: locale));
  }

  @override
  Widget build(BuildContext context) {
    final locale = getLocalizationType(
      widget.localizationType,
    );
    return BlocProvider(
      create: (context) => SoliqIdBloc(
        getIt<SoliqIdRepository>(),
      ),
      child: FaceIdSignIn(
        pinfl: widget.pinfl,
      ),
    );
  }

  Future<void> getGuid() async {
    final locale = getLocalizationType(
      widget.localizationType,
    );
    await preference.setLang(locale);
    await preference.setGUID(widget.guid);
    await Future.delayed(const Duration(seconds: 2));
  }

  @override
  void dispose() async {
    await preference.removeGUID();
    super.dispose();
  }
}
